@@ -2,9 +2,11 @@ import requests
 import urllib3
 import time
 import functools
-from log import log
+import logging
 from typing import List, Dict, Any, Optional
 
+log=logging.getLogger(__name__)
+
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 def enter_and_leave_function(func):
@@ -324,7 +326,7 @@ class CloudPods:
                 server_ids.append(server_info["body"]["id"])
         else:
             # 未找到服务器ID，记录警告
-            log.warn(f"创建服务器失败，未获取到server_id，返回结果: {create_result}")
+            log.warning(f"创建服务器失败，未获取到server_id，返回结果: {create_result}")
 
         return server_ids
 
@@ -334,16 +336,16 @@ class CloudPods:
             url = self.__compute_url + f"/servers/{server_id}"
             rs = self.__session.get(url=url, verify=False, timeout=600)
             if rs.status_code != 200:
-                log.warn(f"Failed to request /servers/{server_id}: Error. err msg is {str(rs.text)}")
+                log.warning(f"Failed to request /servers/{server_id}: Error. err msg is {str(rs.text)}")
                 return None
             try:
                 rs_data = rs.json()
                 return rs_data
             except Exception as e:
-                log.warn(f"Failed to request /servers/{server_id}: Error. err msg is {str(e)}")
+                log.warning(f"Failed to request /servers/{server_id}: Error. err msg is {str(e)}")
                 return None
         except Exception as e:
-            log.warn(f"Failed to request /servers/{server_id}: Error.\rerr msg is {str(e)}")
+            log.warning(f"Failed to request /servers/{server_id}: Error.\rerr msg is {str(e)}")
             return None
 
     @enter_and_leave_function
@@ -355,7 +357,7 @@ class CloudPods:
             }
             rs = self.__session.post(url=url, json=payload,verify=False, timeout=600)
             if rs.status_code != 200:
-                log.warn(f"Failed to request /servers/{server_id}/restart: Error. err msg is {str(rs.text)}")
+                log.warning(f"Failed to request /servers/{server_id}/restart: Error. err msg is {str(rs.text)}")
                 return False
             log.info(f"restart server {server_id} success.")
             return True
@@ -367,16 +369,16 @@ class CloudPods:
     def get_server_ip(self, server_id):
         server = self.get_server_detail(server_id)
         if "server" not in server.keys():
-            log.warn(f"failed get server info by server name {server_id}, server info is {server}.")
+            log.warning(f"failed get server info by server name {server_id}, server info is {server}.")
             return None
         if "nics" not in server["server"].keys():
-            log.warn(f"nics not in server['server'], server['server'] is {server['server']}")
+            log.warning(f"nics not in server['server'], server['server'] is {server['server']}")
             return None
         if len(server["server"]["nics"])<1:
-            log.warn(f"server['server']['nics'] has no elem, its length is 0")
+            log.warning(f"server['server']['nics'] has no elem, its length is 0")
             return None
         if "ip_addr" not in server["server"]["nics"][0].keys():
-            log.warn(f"ip_addr do not in server['server']['nics'][0], server['server']['nics'][0] is {server['server']['nics'][0]}")
+            log.warning(f"ip_addr do not in server['server']['nics'][0], server['server']['nics'][0] is {server['server']['nics'][0]}")
             return None
         return server["server"]["nics"][0]["ip_addr"]
 
@@ -386,21 +388,21 @@ class CloudPods:
         running_status_count = 0
         while True:
             if time_cost>=timeout:
-                log.warn(f"Timeout Error: {timeout} seconds passed but server still not online: Error.")
+                log.warning(f"Timeout Error: {timeout} seconds passed but server still not online: Error.")
                 return False
             server_detail = self.get_server_detail(server_id)
             if "server" in server_detail.keys() and "status" in server_detail["server"].keys():
                 if server_detail["server"]["status"] == "disk_fail":
-                    log.warn(f"server_id: {server_id} disk_fail")
+                    log.warning(f"server_id: {server_id} disk_fail")
                     return False
                 if server_detail["server"]["status"] == "deploy_fail":
-                    log.warn(f"server_id: {server_id} deploy_fail")
+                    log.warning(f"server_id: {server_id} deploy_fail")
                     return False
                 if server_detail["server"]["status"] == "ready":
-                    log.warn(f"server_id: {server_id} ready")
+                    log.warning(f"server_id: {server_id} ready")
                     return False
                 if "_fail" in server_detail["server"]["status"]:
-                    log.warn(f"server_id: {server_id} {server_detail['server']['status']}")
+                    log.warning(f"server_id: {server_id} {server_detail['server']['status']}")
                     return False
                 if server_detail["server"]["status"] == "running":
                     log.info(f"server_id: {server_id} running")
@@ -409,7 +411,7 @@ class CloudPods:
                         log.info(f"server_id: {server_id} running for 5 times check.")
                         return True
                     else:
-                        log.warn(f"just {running_status_count} times check: server_id: {server_id} running status: {server_detail['server']['status']}")
+                        log.warning(f"just {running_status_count} times check: server_id: {server_id} running status: {server_detail['server']['status']}")
                         time.sleep(1)
                         time_cost+=1
                         continue
@@ -418,7 +420,7 @@ class CloudPods:
                 time.sleep(5)
                 time_cost+=5
             else:
-                log.warn(f"Failed to get server_detail: Error. server_detail is: {server_detail}")
+                log.warning(f"Failed to get server_detail: Error. server_detail is: {server_detail}")
                 return False
 
     @enter_and_leave_function
@@ -438,11 +440,11 @@ class CloudPods:
             try:
                 rs_data = rs.json()
                 if "servers" not in rs_data.keys():
-                    log.warn(f"Failed to get server_detail: Error. server_detail is: {rs_data}")
+                    log.warning(f"Failed to get server_detail: Error. server_detail is: {rs_data}")
                     return False
                 return bool(rs_data["servers"])
             except Exception as e:
-                log.warn(f"Failed to get server_detail: Error. server_detail is: {str(e)}")
+                log.warning(f"Failed to get server_detail: Error. server_detail is: {str(e)}")
                 return False
         except Exception as e:
             log.error(f"Failed to request /servers: Error.\rerr msg is {str(e)}",exc_info=True)
@@ -464,7 +466,7 @@ class CloudPods:
                 rs_data = rs.json()
                 return rs_data
             except Exception as e:
-                log.warn(f"Failed to get host spec: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
+                log.warning(f"Failed to get host spec: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
                 return None
         except Exception as e:
             log.error(f"Failed to request /hosts/{host_id}/spec: Error.\rerr msg is {str(e)}",exc_info=True)
@@ -487,10 +489,10 @@ class CloudPods:
                 rs_data = rs.json()
                 return rs_data
             except Exception as e:
-                log.warn(f"Failed to get baremetal hosts: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
+                log.warning(f"Failed to get baremetal hosts: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
                 return None
         except Exception as e:
-            log.warn(f"Failed to request /hosts: Error.\rerr msg is {str(e)}",exc_info=True)
+            log.warning(f"Failed to request /hosts: Error.\rerr msg is {str(e)}",exc_info=True)
             return None
 
     @enter_and_leave_function
@@ -510,7 +512,7 @@ class CloudPods:
                 rs_data = rs.json()
                 return rs_data
             except Exception as e:
-                log.warn(f"Failed to get baremetal servers: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
+                log.warning(f"Failed to get baremetal servers: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
                 return None
         except Exception as e:
             log.error(f"Failed to request /servers: Error.\rerr msg is {str(e)}", exc_info=True)
@@ -524,9 +526,9 @@ class CloudPods:
                 if server_detail is None:
                     log.info(f"server_id: {server_id} deleted")
                     return True
-                log.warn(f"server_id: {server_id} is deleting")
+                log.warning(f"server_id: {server_id} is deleting")
                 time.sleep(5)
-            log.warn(f"Failed to wait for server {server_id} is deleted: Error.\nserver_detail is {server_detail}")
+            log.warning(f"Failed to wait for server {server_id} is deleted: Error.\nserver_detail is {server_detail}")
             return False
         except Exception as e:
             log.error(f"Failed to wait for server {server_id} is deleted: Error.\rerr msg is {str(e)}",exc_info=True)
